==> apache-pulsar-2.10.0-src.tar.gz: apache-pulsar-2.10.0-src/pulsar-functions/instance/src/main/java/org/apache/pulsar/functions/instance/stats/FunctionCollectorRegistry.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.pulsar.functions.instance.stats;

import io.prometheus.client.Collector;
import io.prometheus.client.CollectorRegistry;

/**
 * Internal representation of Prometheus Collector Registry
 */
public abstract class FunctionCollectorRegistry extends CollectorRegistry {
    public static FunctionCollectorRegistry getDefaultImplementation() {
        return new FunctionCollectorRegistryImpl();
    }

    /**
     * Register a metric if it does not yet exist.  If it does exist, then return the existing metric.
     * Currently, only needed by the LocalRunner when running in threaded and exposing metrics via a http server.
     * This method helps resolve the conflict in which multiple instances within the LocalRunner process try to register the same metric.
     * @param metricName the name of the metric
     * @param collector the metric object e.g. Count, Gauge, etc.
     * @param <T>
     * @return If the metric with the name `metricName` already exists, return the existing metric object.  If not, return null
     */
    public abstract <T extends Collector> T registerIfNotExist(String metricName, T collector);
}

==> apache-pulsar-2.11.1-src.tar.gz: apache-pulsar-2.11.1-src/pulsar-functions/instance/src/main/java/org/apache/pulsar/functions/instance/stats/FunctionCollectorRegistry.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.pulsar.functions.instance.stats;

import io.prometheus.client.Collector;
import io.prometheus.client.CollectorRegistry;

/**
 * Internal representation of Prometheus Collector Registry.
 */
public abstract class FunctionCollectorRegistry extends CollectorRegistry {
    public static FunctionCollectorRegistry getDefaultImplementation() {
        return new FunctionCollectorRegistryImpl();
    }

    /**
     * Register a metric if it does not yet exist.  If it does exist, then return the existing metric.
     * Currently, only needed by the LocalRunner when running in threaded and exposing metrics via a http server.
     * This method helps resolve the conflict in which multiple instances within
     * the LocalRunner process try to register the same metric.
     * @param metricName the name of the metric
     * @param collector the metric object e.g. Count, Gauge, etc.
     * @param <T>
     * @return If the metric with the name `metricName` already exists, return the existing metric object.
     * If not, return null
     */
    public abstract <T extends Collector> T registerIfNotExist(String metricName, T collector);
}
